(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[34],{1804:function(e,t,r){"use strict";r.r(t),r.d(t,"default",(function(){return d}));var n=r(0),s=r.n(n),o=r(76),i=r(27),a=r(62),c=r(71),l=r(9),u=r(1180),m=r(171),g=Object(l.a)(u.a,{shouldForwardProp:m.a,target:"e17lx80j1"})((function(e){var t=e.theme,r=e.$usingCustomTheme;return{marginTop:t.spacing.none,marginBottom:t.spacing.none,marginRight:t.spacing.none,marginLeft:t.spacing.none,borderColor:t.colors.fadedText10,borderTopColor:r?t.colors.primary:t.colors.blue70,flexGrow:0,flexShrink:0}}),""),h=Object(l.a)("div",{target:"e17lx80j0"})((function(e){return{display:"flex",gap:e.theme.spacing.lg,alignItems:"center",width:"100%"}}),""),p=r(1);var d=function(e){var t=e.width,r=e.element,n=Object(o.c)(),l=s.a.useContext(c.a).activeTheme,u=!Object(i.isPresetTheme)(l),m={width:t};return Object(p.jsx)("div",{className:"stSpinner",style:m,children:Object(p.jsxs)(h,{children:[Object(p.jsx)(g,{$size:n.iconSizes.twoXL,$usingCustomTheme:u}),Object(p.jsx)(a.a,{source:r.text,allowHTML:!1})]})})}}}]);