(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[42],{1812:function(t,e,r){"use strict";r.r(e),r.d(e,"default",(function(){return o}));var i=r(0),n=r(71),c=r(34),s=r(62),a=r(66),l=r(1);var o=function(t){var e=t.disabled,r=t.element,o=t.widgetMgr,d={width:t.width},u=Object(i.useContext)(n.a).getBaseUriParts;return Object(l.jsx)("div",{className:"row-widget stDownloadButton",style:d,children:Object(l.jsx)(c.a,{help:r.help,children:Object(l.jsx)(c.d,{kind:c.b.SECONDARY,size:c.c.SMALL,disabled:e,onClick:function(){o.setTriggerValue(r,{fromUi:!0});var t=document.createElement("a"),e="".concat(Object(a.b)(r.url,u()),"?title=").concat(encodeURIComponent(document.title));t.setAttribute("href",e),t.setAttribute("target","_blank"),t.click()},children:Object(l.jsx)(s.a,{source:r.label,allowHTML:!1,isButton:!0})})})})}}}]);