(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[26],{1666:function(t,e){},1800:function(t,e,i){"use strict";i.r(e),i.d(e,"default",(function(){return g}));var r,n=i(0),a=i(1637),o=i.n(a),c=i(71),s=i(216),d=i(66),l=i(9),u=Object(l.a)("div",{target:"etr89bj2"})((function(t){return{display:"flex",flexDirection:"row",flexWrap:"wrap",rowGap:t.theme.spacing.lg}}),""),h=Object(l.a)("div",{target:"etr89bj1"})((function(t){t.theme;return{display:"flex",flexDirection:"column",alignItems:"stretch",width:"auto",flexGrow:0}}),""),f=Object(l.a)("div",{target:"etr89bj0"})((function(t){var e=t.theme;return{fontFamily:e.genericFonts.bodyFont,fontSize:e.fontSizes.sm,color:e.colors.fadedText60,textAlign:"center",marginTop:e.spacing.xs,wordWrap:"break-word",padding:"0.125rem"}}),""),m=i(1);!function(t){t[t.OriginalWidth=-1]="OriginalWidth",t[t.ColumnWidth=-2]="ColumnWidth",t[t.AutoWidth=-3]="AutoWidth"}(r||(r={}));var g=Object(s.a)((function(t){var e,i=t.width,a=t.isFullScreen,s=t.element,l=t.height,g=Object(n.useContext)(c.a).getBaseUriParts,b=s.width;if(b===r.OriginalWidth||b===r.AutoWidth)e=void 0;else if(b===r.ColumnWidth)e=i;else{if(!(b>0))throw Error("Invalid image width: ".concat(b));e=b}var p={};return l&&a?(p.maxHeight=l,p["object-fit"]="contain"):(p.width=e,b===r.AutoWidth&&(p.maxWidth="100%")),Object(m.jsx)(u,{style:{width:i},children:s.imgs.map((function(t,e){var i=t;return Object(m.jsxs)(h,{"data-testid":"stImage",children:[i.markup?o()(Object(d.g)(i.markup)):Object(m.jsx)("img",{style:p,src:Object(d.b)(i.url,g()),alt:e.toString()}),i.caption&&Object(m.jsx)(f,{"data-testid":"caption",style:p,children:" ".concat(i.caption," ")})]},e)}))})}))}}]);